Mode

Enum Mode 

#[non_exhaustive]
#[repr(u8)]
pub enum Mode {
Show 16 variants Stopped = 0, Fault = 1, Enabling = 2, Calibrating = 3, CalibrationComplete = 4, Pwm = 5, Voltage = 6, VoltageFoc = 7, VoltageDq = 8, Current = 9, Position = 10, Timeout = 11, ZeroVelocity = 12, StayWithin = 13, MeasureInd = 14, Brake = 15,
}
The operating mode of a moteus controller.

This corresponds to the value in the Register::Mode register.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Stopped = 0

Motor is stopped and unpowered



Fault = 1

Controller is in a fault state



Enabling = 2

Controller is enabling (transitioning to active)



Calibrating = 3

Controller is calibrating



CalibrationComplete = 4

Calibration is complete



Pwm = 5

Raw PWM mode



Voltage = 6

Voltage mode



VoltageFoc = 7

Voltage FOC mode



VoltageDq = 8

Voltage DQ mode



Current = 9

Current (torque) mode



Position = 10

Position mode (primary operating mode)



Timeout = 11

Position timeout (watchdog expired)



ZeroVelocity = 12

Zero velocity mode (hold position with damping)



StayWithin = 13

Stay within bounds mode



MeasureInd = 14

Measure inductance mode (calibration)



Brake = 15

Brake mode (short motor windings)

Implementations

Source

impl Mode

pub fn is_error(&self) -> bool

Returns true if the controller is in an error state.

Examples
use moteus_protocol::Mode;

let mode = Mode::Position;
assert!(mode.is_active());
assert!(!mode.is_error());

let fault = Mode::Fault;
assert!(fault.is_error());
assert!(!fault.is_active());
pub fn is_active(&self) -> bool

Returns true if the controller is actively controlling the motor.