Resolution

Enum Resolution 

#[non_exhaustive]
#[repr(i8)]
pub enum Resolution { Int8 = 0, Int16 = 1, Int32 = 2, Float = 3, Ignore = 4, }
The resolution (data type) used when encoding or decoding a register value.

Each resolution type determines:

  • The number of bytes used on the wire
  • The scaling applied to convert between wire format and physical units
  • The range of representable values

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Int8 = 0

8-bit signed integer (1 byte)



Int16 = 1

16-bit signed integer (2 bytes)



Int32 = 2

32-bit signed integer (4 bytes)



Float = 3

32-bit IEEE 754 float (4 bytes)



Ignore = 4

This register should be ignored/not transmitted

Implementations

Source

impl Resolution

pub const fn size(self) -> usize

Returns the size in bytes for this resolution type.

Returns 0 for Ignore.

pub const fn type_code(self) -> u8

Returns the multiplex protocol type code for this resolution.

This is used in the wire protocol to identify the data type.

pub const fn from_type_code(code: u8) -> Option<Resolution>

Creates a Resolution from a type code.

Returns None if the type code is invalid.

pub const fn nan_value(self) -> i32

Returns the minimum representable value for integer types.

This value is used to represent NaN in the protocol.

pub const fn max_value(self) -> i32

Returns the maximum representable value for integer types.